==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kinesisanalyticsv2/kotlin/inputs/ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesisanalyticsv2.kotlin.inputs

import com.pulumi.aws.kinesisanalyticsv2.inputs.ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property recordFormatType Specifies the format of the records on the output stream. Valid values: `CSV`, `JSON`.
 */
public data class
ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs(
    public val recordFormatType: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.kinesisanalyticsv2.inputs.ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs> {
    override fun toJava():
        com.pulumi.aws.kinesisanalyticsv2.inputs.ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs =
        com.pulumi.aws.kinesisanalyticsv2.inputs.ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs.builder()
            .recordFormatType(recordFormatType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs].
 */
@PulumiTagMarker
public class
ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgsBuilder
internal constructor() {
    private var recordFormatType: Output<String>? = null

    /**
     * @param value Specifies the format of the records on the output stream. Valid values: `CSV`, `JSON`.
     */
    @JvmName("gdwrbtsfqcoxtgfl")
    public suspend fun recordFormatType(`value`: Output<String>) {
        this.recordFormatType = value
    }

    /**
     * @param value Specifies the format of the records on the output stream. Valid values: `CSV`, `JSON`.
     */
    @JvmName("vvkdrmscovalfiym")
    public suspend fun recordFormatType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recordFormatType = mapped
    }

    internal fun build():
        ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs =
        ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs(
            recordFormatType = recordFormatType ?: throw PulumiNullFieldException("recordFormatType"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kinesisanalyticsv2/kotlin/inputs/ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesisanalyticsv2.kotlin.inputs

import com.pulumi.aws.kinesisanalyticsv2.inputs.ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property recordFormatType Specifies the format of the records on the output stream. Valid values: `CSV`, `JSON`.
 */
public data class
ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs(
    public val recordFormatType: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.kinesisanalyticsv2.inputs.ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs> {
    override fun toJava(): com.pulumi.aws.kinesisanalyticsv2.inputs.ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs =
        com.pulumi.aws.kinesisanalyticsv2.inputs.ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs.builder()
            .recordFormatType(recordFormatType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs].
 */
@PulumiTagMarker
public class
ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgsBuilder
internal constructor() {
    private var recordFormatType: Output<String>? = null

    /**
     * @param value Specifies the format of the records on the output stream. Valid values: `CSV`, `JSON`.
     */
    @JvmName("dbdgvfbyolqaufwe")
    public suspend fun recordFormatType(`value`: Output<String>) {
        this.recordFormatType = value
    }

    /**
     * @param value Specifies the format of the records on the output stream. Valid values: `CSV`, `JSON`.
     */
    @JvmName("ugyfvrjlldsdsvrl")
    public suspend fun recordFormatType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recordFormatType = mapped
    }

    internal fun build(): ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs =
        ApplicationApplicationConfigurationSqlApplicationConfigurationOutputDestinationSchemaArgs(
            recordFormatType = recordFormatType ?: throw PulumiNullFieldException("recordFormatType"),
        )
}
